#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-IGpdi92kVk9oElCRBByIR
key:                  data-clist-0.2-IGpdi92kVk9oElCRBByIR
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  c3eeda958bb4585931596798462332f1
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-clist-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-IGpdi92kVk9oElCRBByIR
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

